@@ -6,12 +6,18 @@ from pathlib import Path
 
 # ----------------------------------------------------------------------------------------------------------------------------
 # REUSE
-def init_logging(logName:str = "./log.runlog", loggingLevel = logging.INFO):
-
-    LOG_NAME = logName
+def init_logging(logPath_:str = "./log.runlog", level_ = logging.INFO, append:bool = True):
+    """
+    Initialize the logging system which will write to a file and to the console.
+    """
+    LOG_PATH = logPath_
     LOG_FORMAT = "%(asctime)s %(name)s:%(levelname)s:%(message)s"
 
-    fileHandler = logging.FileHandler(filename=LOG_NAME, encoding='utf-8', mode='a+')
+    useMode = 'w'
+    if append:
+        useMode = 'a'
+
+    fileHandler = logging.FileHandler(filename=LOG_PATH, encoding='utf-8', mode=useMode)
 
     # also this:
     # https://pythonhowtoprogram.com/logging-in-python-3-how-to-output-logs-to-file-and-console/
@@ -25,7 +31,7 @@ def init_logging(logName:str = "./log.runlog", loggingLevel = logging.INFO):
     logging.basicConfig(handlers=[fileHandler, streamHandler],
                         format=LOG_FORMAT, 
                         datefmt="%F %A %T",
-                        level=loggingLevel)
+                        level=level_)
 
 
 # ----------------------------------------------------------------------------------------------------------------------------
